==> wrogue-0.7.4.tar.bz2: wrogue-0.7.4/src/ui/ui_color.h <==
/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * Module Name: Ui
 * Description: -
 */

/*
 * Colors
 */

#define MAX_COLORS			38
#define MAX_ANSI_COLORS			16

#define C_DEFAULT			C_SILVER

#define C_HIGHLIGHT			C_YELLOW
#define C_TEXT				C_SILVER
#define C_FIELD_VALUE			C_SILVER
#define C_FIELD_VALUE_INCREASED		C_LIME
#define C_FIELD_VALUE_REDUCED		C_RED
#define C_FIELD_NAME			C_GRAY
#define C_HEADER			C_GRAY
#define C_HOTKEY			C_SILVER
#define C_HOTKEY_BRACKET		C_GRAY
#define C_SEC_SCREEN_TITLE		C_GRAY
#define C_WARNING			C_RED
#define C_INJURED			C_MAROON

/* terrain type colors */
#define C_FLOOR				C_METAL
#define C_RUSTY_FLOOR			C_RUSTY
#define C_CHEMICAL_SLUDGE		C_RADIOACTIVE
#define C_BLOODY_CORPSE			C_BLOOD
#define C_BODY_PART			C_BLOOD
#define C_BLOODY_FLOOR			C_BLOOD
#define C_WALL				C_RUSTY
#define C_BLOODY_WALL			C_BLOOD

/* status flag colors */
#define C_UNIQUE			C_SILVER
#define C_DAEMONIC			C_RED
#define C_MACHINE			C_METAL
#define C_BOSS				C_GOLD
#define C_STUNNED			C_TEAL
#define C_POISONED			C_POISON_GREEN
#define C_DISEASED			C_OLIVE
#define C_BROKEN			C_METAL
#define C_PSYCHIC_OVERLOAD		C_RED
#define C_PSY_POWER			C_WARLOCK_PURPLE
#define C_DRUG				C_JADE
#define C_UNNOTICED			C_GRAY
#define C_CANNOT_SPEAK			C_SILVER

/* cursor colors */
#define C_CURSOR			C_YELLOW
#define C_AGGRESSIVE_CURSOR		C_RED
#define C_PSY_CURSOR			C_PSY_POWER



const RGB_DATA *	color_rgb(COLOR);
ANSI_COLOR		color_ansi(COLOR);

COLOR			dynamic_color(const DYNAMIC_COLOR *);

COLOR			name_to_color(const char *);

==> wrogue-0.7.5.tar.bz2: wrogue-0.7.5/src/ui/ui_color.h <==
/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * Module Name: Ui
 * Description: -
 */

/*
 * Colors
 */

#define MAX_COLORS			33
#define MAX_ANSI_COLORS			16

#define C_DEFAULT			C_SILVER

#define C_HIGHLIGHT			C_YELLOW
#define C_TEXT				C_SILVER
#define C_FIELD_VALUE			C_SILVER
#define C_FIELD_VALUE_INCREASED		C_LIME
#define C_FIELD_VALUE_REDUCED		C_RED
#define C_FIELD_NAME			C_GRAY
#define C_HEADER			C_GRAY
#define C_HOTKEY			C_SILVER
#define C_HOTKEY_BRACKET		C_GRAY
#define C_SEC_SCREEN_TITLE		C_GRAY
#define C_WARNING			C_RED
#define C_INJURED			C_BLOOD

/* terrain type colors */
#define C_FLOOR				C_METAL
#define C_RUSTY_FLOOR			C_RUSTY
#define C_CHEMICAL_SLUDGE		C_RADIOACTIVE
#define C_BLOODY_CORPSE			C_BLOOD
#define C_BODY_PART			C_BLOOD
#define C_BLOODY_FLOOR			C_BLOOD
#define C_WALL				C_RUSTY
#define C_BLOODY_WALL			C_BLOOD

/* status flag colors */
#define C_UNIQUE			C_SILVER
#define C_DAEMONIC			C_RED
#define C_MACHINE			C_METAL
#define C_BOSS				C_GOLD
#define C_STUNNED			C_TEAL
#define C_POISONED			C_POISON_GREEN
#define C_DISEASED			C_OLIVE
#define C_BROKEN			C_METAL
#define C_PSYCHIC_OVERLOAD		C_RED
#define C_PSY_POWER			C_WARLOCK_PURPLE
#define C_DRUG				C_JADE
#define C_UNNOTICED			C_GRAY
#define C_CANNOT_SPEAK			C_SILVER

/* cursor colors */
#define C_CURSOR			C_YELLOW
#define C_AGGRESSIVE_CURSOR		C_RED
#define C_PSY_CURSOR			C_PSY_POWER


/*
 * ANSI colors
 */
typedef enum {

	ANSI_NIL = -1,
	
	ANSI_BLACK,
	ANSI_RED,
	ANSI_GREEN,
	ANSI_BROWN,
	ANSI_BLUE,
	ANSI_MAGENTA,
	ANSI_CYAN,
	ANSI_LIGHT_GRAY,
	ANSI_DARK_GRAY,
	ANSI_LIGHT_RED,
	ANSI_LIGHT_GREEN,
	ANSI_YELLOW,
	ANSI_LIGHT_BLUE,
	ANSI_LIGHT_MAGENTA,
	ANSI_LIGHT_CYAN,
	ANSI_WHITE,
	
	ANSI_OUT_OF_BOUNDS

} ANSI_COLOR;



const RGB_DATA *	color_rgb(COLOR);
ANSI_COLOR		color_ansi(COLOR);

COLOR			dynamic_color(const DYNAMIC_COLOR *);

COLOR			name_to_color(const char *);
